# Perfsprocket

Spin through files and file sequences with ease!

## Installation

``pip install perfsprocket``

## Getting Started
For full documentation:
[read the docs](https://illuscio-dev.github.io/perfsprocket-py/).

For library development guide, 
[read the docs](https://illuscio-dev.github.io/islelib-py/).

### Prerequisites

Python 3.6+

## Authors

* **Billy Peake** - *Initial work*
